@@ -1,22 +1,14 @@
 import argparse
-import math
-import os
-import shutil
 import sys
-import tempfile
-import textwrap
 from copy import deepcopy
-from datetime import datetime, timedelta
+from datetime import datetime
 from pathlib import Path
 from sqlite3 import OperationalError
 from timeit import default_timer as timer
-from typing import Dict, List, Tuple
+from typing import Dict, List
 
-import humanize
-import numpy as np
 import pandas as pd
 import yt_dlp
-from tabulate import tabulate
 
 from xklb.db import sqlite_con
 from xklb.tube_actions import default_ydl_opts
@@ -27,7 +19,6 @@ from xklb.utils import (
     log,
     safe_unpack,
     single_column_tolist,
-    stop,
 )
 
 
@@ -149,10 +140,10 @@ def consolidate(playlist_path, v):
         "requested_entries",
         "thumbnails",
         "playlist_count",
-        'playlist_id',
-        'playlist_title',
-        'playlist_uploader',
-        'playlist_uploader_id',
+        "playlist_id",
+        "playlist_title",
+        "playlist_uploader",
+        "playlist_uploader_id",
     ]
 
     if v.get("title") in ["[Deleted video]", "[Private video]"]:
@@ -276,7 +267,7 @@ def process_playlist(args, playlist_path) -> (List[Dict] | None):
                 uploader=safe_unpack(pl.get("playlist_uploader_id"), pl.get("playlist_uploader")),
                 id=pl.get("playlist_id"),
             )
-            if entry["path"] == pl["path"] or not pl.get('id'):
+            if entry["path"] == pl["path"] or not pl.get("id"):
                 log.warning("Importing playlist-less media %s", pl["path"])
             elif playlist_known(args, playlist_path):
                 pass
@@ -337,98 +328,3 @@ def tube_update():
         process_playlist(args, playlist)
         end = timer()
         log.info(f"{end - start:.1f} seconds to update playlist")
-
-
-def human_time(hours):
-    if hours is None or np.isnan(hours):
-        return None
-    return humanize.precisedelta(timedelta(hours=int(hours), minutes=math.ceil(hours % 1 * 60)), minimum_unit="minutes")
-
-
-def printer(args):
-    query = "select distinct ie_key, title, path from playlists"
-    if "a" in args.print:
-        query = f"""select
-            playlists.ie_key
-            , playlists.title
-            , coalesce(playlists.path, "Playlist-less videos") path
-            , sum(media.duration/60.0/60.0) hours
-            , sum(media.size) size
-            , count(*) count
-        from media
-        left join playlists on playlists.path = media.playlist_path
-        group by coalesce(playlists.path, "Playlist-less videos")"""
-
-    db_resp = pd.DataFrame([dict(r) for r in args.con.execute(query).fetchall()])
-
-    if "f" in args.print:
-        print(db_resp[["path"]].to_string(index=False, header=False))
-    else:
-        tbl = db_resp.copy()
-        tbl[["path"]] = tbl[["path"]].applymap(
-            lambda x: textwrap.fill(x, max(10, os.get_terminal_size().columns - (15 * len(tbl.columns))))
-        )
-        if "uploader_url" in tbl.columns:
-            tbl[["uploader_url"]] = tbl[["uploader_url"]].applymap(
-                lambda x: None
-                if x is None
-                else textwrap.fill(x, max(10, os.get_terminal_size().columns - (40 * len(tbl.columns))))
-            )
-
-        if "size" in tbl.columns:
-            tbl[["size"]] = tbl[["size"]].applymap(lambda x: None if x is None else humanize.naturalsize(x))
-        if "hours" in tbl.columns:
-            tbl[["hours"]] = tbl[["hours"]].applymap(lambda x: None if x is None else human_time(x))
-
-        print(tabulate(tbl, tablefmt="fancy_grid", headers="keys", showindex=False))  # type: ignore
-
-        if "hours" in db_resp.columns:
-            summary = db_resp.sum(numeric_only=True)
-            hours = summary.get("hours") or 0.0
-            print("Total duration:", human_time(hours))
-
-    stop()
-
-
-def delete_playlists(args, playlists):
-    args.con.execute(
-        "delete from media where playlist_path in (" + ",".join(["?"] * len(playlists)) + ")", (*playlists,)
-    )
-    args.con.execute("delete from playlists where path in (" + ",".join(["?"] * len(playlists)) + ")", (*playlists,))
-    args.con.commit()
-
-
-def tube_list():
-    parser = argparse.ArgumentParser()
-    parser.add_argument("db", nargs="?", default="tube.db")
-    parser.add_argument(
-        "--print",
-        "-p",
-        nargs="*",
-        default="p",
-        choices=["p", "f", "a"],
-        help="""tubelist -p a -- means print playlists in a table
-tubelist -p a -- means print an aggregate report
-tubelist -p f -- means print only playlist urls -- useful for piping to other utilities like xargs or GNU Parallel""",
-    )
-    parser.add_argument(
-        "--delete",
-        "--remove",
-        "--erase",
-        "--rm",
-        "-rm",
-        "-d",
-        nargs="+",
-        help="""lb tubelist -rm https://vimeo.com/canal180 -- removes the playlist/channel and all linked videos""",
-    )
-    parser.add_argument("-v", "--verbose", action="count", default=0)
-    args = parser.parse_args()
-    log.info(filter_None(args.__dict__))
-
-    args.con = sqlite_con(args.db)
-
-    if args.delete:
-        delete_playlists(args, args.delete)
-        stop()
-
-    printer(args)
